@@ -53,7 +53,7 @@ PlotciAAll<-function(n,alp,h)
                                            xmin = LowerLimit,
                                            xmax = UpperLimit,
                                            color= method),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -70,7 +70,7 @@ PlotciAAll<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit, color= method),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
@@ -132,7 +132,7 @@ PlotciAAllg<-function(n,alp,h)
                                              xmin = LowerLimit,
                                              xmax = UpperLimit,
                                              color= method),
-                                width = 0.5)+
+                                size = 0.5)+
         ggplot2::geom_point(data=ldf,
                             ggplot2::aes(x=Value, y=ID,
                                          group = Abberation,shape=Abberation),
@@ -149,7 +149,7 @@ PlotciAAllg<-function(n,alp,h)
                                 ggplot2::aes(x = UpperLimit,y = ID,
                                              xmin = LowerLimit,
                                              xmax = UpperLimit, color= method),
-                                width = 0.5)
+                                size = 0.5)
     }
     oo
   }
@@ -166,7 +166,7 @@ PlotciAAllg<-function(n,alp,h)
                                              xmin = LowerLimit,
                                              xmax = UpperLimit,
                                              color= method),
-                                width = 0.5)+
+                                size = 0.5)+
         ggplot2::geom_point(data=ldf,
                             ggplot2::aes(x=Value, y=ID,
                                          group = Abberation,shape=Abberation),
@@ -185,7 +185,7 @@ PlotciAAllg<-function(n,alp,h)
                                 ggplot2::aes(x = UpperLimit,y = ID,
                                              xmin = LowerLimit,
                                              xmax = UpperLimit, color= method),
-                                width = 0.5) +
+                                size = 0.5) +
         ggplot2::geom_hline(ggplot2::aes(yintercept=val1),data=ff) +
         ggplot2::geom_text(ggplot2::aes(0,val1,label = paste("x=", sep="", val2),hjust=1.1, vjust = -1), data=ff)
     }
@@ -249,7 +249,7 @@ PlotciAWD<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -265,7 +265,7 @@ PlotciAWD<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
@@ -327,7 +327,7 @@ PlotciAAS<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -343,7 +343,7 @@ PlotciAAS<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
@@ -405,7 +405,7 @@ PlotciALR<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -421,7 +421,7 @@ PlotciALR<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
@@ -482,7 +482,7 @@ PlotciASC<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -498,7 +498,7 @@ PlotciASC<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
@@ -559,7 +559,7 @@ PlotciALT<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -575,7 +575,7 @@ PlotciALT<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
@@ -635,7 +635,7 @@ PlotciATW<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)+
+                              size = 0.5)+
       ggplot2::geom_point(data=ldf,
                           ggplot2::aes(x=Value, y=ID,
                                        group = Abberation,shape=Abberation),
@@ -651,7 +651,7 @@ PlotciATW<-function(n,alp,h)
                               ggplot2::aes(x = UpperLimit,y = ID,
                                            xmin = LowerLimit,
                                            xmax = UpperLimit),
-                              width = 0.5)
+                              size = 0.5)
   }
   oo
 }
